pub struct PermissionCheckFactory<F>where
F: Fn(State<App>, Auth, Path<String>, Request<Body>, Next) -> PermissionCheckOutput + Clone + Send + Sync,{ /* private fields */ }Expand description
Wrapper struct for permission check middleware factories
This struct wraps a closure that implements the permission check middleware pattern. It takes a static permission action string and returns a middleware factory function.
Implementations
Sourceimpl<F> PermissionCheckFactory<F>
impl<F> PermissionCheckFactory<F>