pub struct Scheduler<S: Clone> { /* private fields */ }Implementations
Sourceimpl<S: Clone + Send + Sync + 'static> Scheduler<S>
impl<S: Clone + Send + Sync + 'static> Scheduler<S>
pub fn new(store: Arc<dyn TaskStore<S>>) -> Arc<Self>
pub fn start(&self, state: S)
pub fn register<T: Task<S>>(&self) -> ClResult<&Self>
Sourcepub fn task(&self, task: Arc<dyn Task<S>>) -> TaskSchedulerBuilder<'_, S>
pub fn task(&self, task: Arc<dyn Task<S>>) -> TaskSchedulerBuilder<'_, S>
Create a builder for scheduling a task using the fluent API
pub async fn add(&self, task: Arc<dyn Task<S>>) -> ClResult<TaskId>
pub async fn add_queue( &self, id: TaskId, task_meta: TaskMeta<S>, ) -> ClResult<TaskId>
Sourcepub async fn health_check(&self) -> ClResult<SchedulerHealth>
pub async fn health_check(&self) -> ClResult<SchedulerHealth>
Get health status of the scheduler Returns information about tasks in each queue and detects anomalies