File access level helpers
Provides functions to determine user access levels to files based on:
- Scoped tokens (file:{file_id}:{R|W} grants Read/Write access)
- Ownership (owner always has Write access)
- FSHR action grants (WRITE subtype = Write, otherwise Read)
Structs
- File
Access Ctx - Context describing the subject requesting file access
- File
Access Result - Result of checking file access
Enums
- File
Access Error - Error type for file access checks
Functions
- check_
file_ access_ with_ scope - Check file access and return file view with access level
- get_
access_ level - Get access level for a user on a file
- get_
access_ level_ with_ scope - Get access level for a user on a file, considering scoped tokens