Rate Limiting System
Hierarchical rate limiting with GCRA algorithm for DDOS protection. Supports multiple address levels (IPv4 /32, /24; IPv6 /128, /64, /48) and includes proof-of-work counter for CONN action abuse prevention.
Structs
- BanEntry
- Ban entry stored in the ban list
- PowConfig
- Proof-of-Work counter configuration
- Rate
Limit Config - Main rate limit configuration
- Rate
Limit Layer - Rate limit middleware layer
- Rate
Limit Manager - Main rate limit manager
- Rate
Limit Status - Current status of rate limiting for an address at a specific level
- Rate
Limit Tier Config - Dual-tier rate limit configuration for a single address level
- Rate
Limiter Stats - Statistics about the rate limiter
Enums
- Address
Key - Represents the hierarchical address level being limited
- Penalty
Reason - Reason for a penalty
- PowError
- Proof-of-work error types
- PowPenalty
Reason - Reason for incrementing the PoW counter
- Rate
Limit Error - Rate limit error types
Traits
- Rate
Limit Api - Internal API for programmatic rate limit management
Functions
- extract_
client_ ip - Extract client IP from request based on ServerMode